texinfo-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[5491] comments updated


From: Gavin D. Smith
Subject: [5491] comments updated
Date: Thu, 24 Apr 2014 13:42:03 +0000

Revision: 5491
          http://svn.sv.gnu.org/viewvc/?view=rev&root=texinfo&revision=5491
Author:   gavin
Date:     2014-04-24 13:42:03 +0000 (Thu, 24 Apr 2014)
Log Message:
-----------
comments updated

Modified Paths:
--------------
    trunk/info/dir.c

Modified: trunk/info/dir.c
===================================================================
--- trunk/info/dir.c    2014-04-24 13:36:40 UTC (rev 5490)
+++ trunk/info/dir.c    2014-04-24 13:42:03 UTC (rev 5491)
@@ -208,9 +208,8 @@
   return node;
 }
 
-/* Given CONTENTS and FB (a file buffer), add the menu found in CONTENTS
-   to the menu found in FB->contents.  Second argument SIZE is the total
-   size of CONTENTS. */
+/* Given CONTENTS and NODE, add the menu found in CONTENTS to the menu
+   found in NODE->contents.  SIZE is the total size of CONTENTS. */
 static void
 add_menu_to_node (char *contents, size_t size, NODE *node)
 {
@@ -227,7 +226,7 @@
   fb_binding.end = node->nodelen;
   fb_binding.flags = S_FoldCase | S_SkipDest;
 
   /* Move to the start of the menus in CONTENTS and FB. */
   if (search_forward (INFO_MENU_LABEL, &contents_binding, &contents_offset)
       != search_success)
     /* If there is no menu in CONTENTS, quit now. */
@@ -238,7 +237,7 @@
      and newline characters. */
   contents_offset += skip_whitespace_and_newlines (contents + contents_offset);
 
   /* If there is no menu in FB, make one. */
   if (search_forward (INFO_MENU_LABEL, &fb_binding, &fb_offset)
       != search_success)
     {
@@ -257,7 +256,7 @@
 
   /* CONTENTS_OFFSET and FB_OFFSET point to the starts of the menus that
      appear in their respective buffers.  Add the remainder of CONTENTS
-     to the end of FB's menu. */
+     to the end of NODE's menu. */
   fb_binding.start = fb_offset;
   fb_offset = find_node_separator (&fb_binding);
   if (fb_offset != -1)
@@ -227,7 +226,7 @@
   fb_binding.flags = S_FoldCase | S_SkipDest;
 
-  /* Move to the start of the menus in CONTENTS and FB. */
+  /* Move to the start of the menus in CONTENTS and NODE. */
   if (search_forward (INFO_MENU_LABEL, &contents_binding, &contents_offset)
       != search_success)
@@ -238,7 +237,7 @@
   contents_offset += skip_whitespace_and_newlines (contents + contents_offset);
 
-  /* If there is no menu in FB, make one. */
+  /* If there is no menu in NODE, make one. */
   if (search_forward (INFO_MENU_LABEL, &fb_binding, &fb_offset)
       != search_success)




reply via email to

[Prev in Thread] Current Thread [Next in Thread]